@@ -534,6 +534,7 @@ class KrakenAPI(object):
             raise KrakenAPIError(res['error'])
 
         # create dataframe
+        pair = list(res['result'].keys())[0]
         ohlc = pd.DataFrame(res['result'][pair])
         last = res['result']['last']
 
@@ -700,6 +701,7 @@ class KrakenAPI(object):
             raise KrakenAPIError(res['error'])
 
         # create dataframe
+        pair = list(res['result'].keys())[0]
         trades = pd.DataFrame(res['result'][pair])
 
         # last timestamp
@@ -792,6 +794,7 @@ class KrakenAPI(object):
             raise KrakenAPIError(res['error'])
 
         # create dataframe
+        pair = list(res['result'].keys())[0]
         spread = pd.DataFrame(res['result'][pair])
 
         # last timestamp
@@ -1202,7 +1205,7 @@ class KrakenAPI(object):
             orders = pd.concat((orders, descr), axis=1)
             for col in ['closetm', 'expiretm', 'opentm', 'starttm']:
                 if col in orders:
-                    orders.loc[:, col] = orders[col].astype(int)
+                    orders.loc[:, col] = orders[col].astype(float)
             for col in ['cost', 'fee', 'price', 'vol', 'vol_exec',
                         'descr_price', 'descr_price2']:
                 orders.loc[:, col] = orders[col].astype(float)
